@@ -7,12 +7,23 @@ These models are based on the MQTT message formats and API responses.
 """
 
 import logging
-from enum import Enum
-from typing import Annotated, Any, Optional, Union
+from typing import Annotated, Any
 
 from pydantic import BaseModel, BeforeValidator, ConfigDict, Field
 from pydantic.alias_generators import to_camel
 
+from .enums import (
+    CurrentOperationMode,
+    DeviceType,
+    DhwOperationSetting,
+    DREvent,
+    ErrorCode,
+    HeatSource,
+    TemperatureType,
+    TempFormulaType,
+    UnitType,
+)
+
 _logger = logging.getLogger(__name__)
 
 
@@ -26,6 +37,14 @@ def _device_bool_validator(v: Any) -> bool:
     return bool(v == 2)
 
 
+def _capability_flag_validator(v: Any) -> bool:
+    """Convert capability flag (2=True/supported, 1=False/not supported).
+
+    Uses same pattern as OnOffFlag: 1=OFF/not supported, 2=ON/supported.
+    """
+    return bool(v == 2)
+
+
 def _div_10_validator(v: Any) -> float:
     """Divide by 10."""
     if isinstance(v, (int, float)):
@@ -73,48 +92,101 @@ def _deci_celsius_to_fahrenheit(v: Any) -> float:
     return float(v)
 
 
+def _tou_status_validator(v: Any) -> bool:
+    """Convert TOU status (0=False/disabled, 1=True/enabled)."""
+    return bool(v == 1)
+
+
+def _tou_override_validator(v: Any) -> bool:
+    """Convert TOU override status (1=True/override active, 2=False/normal).
+
+    Note: This field uses OnOffFlag pattern (1=OFF, 2=ON) but represents
+    whether TOU schedule operation is enabled, not whether override is active.
+    So: 2 (ON) = TOU operating normally = override NOT active = False
+        1 (OFF) = TOU not operating = override IS active = True
+    """
+    return bool(v == 1)
+
+
 # Reusable Annotated types for conversions
 DeviceBool = Annotated[bool, BeforeValidator(_device_bool_validator)]
+CapabilityFlag = Annotated[bool, BeforeValidator(_capability_flag_validator)]
 Div10 = Annotated[float, BeforeValidator(_div_10_validator)]
 HalfCelsiusToF = Annotated[float, BeforeValidator(_half_celsius_to_fahrenheit)]
 DeciCelsiusToF = Annotated[float, BeforeValidator(_deci_celsius_to_fahrenheit)]
+TouStatus = Annotated[bool, BeforeValidator(_tou_status_validator)]
+TouOverride = Annotated[bool, BeforeValidator(_tou_override_validator)]
 
 
 class NavienBaseModel(BaseModel):
-    """Base model for all Navien models."""
+    """Base model for all Navien models.
+
+    Note: use_enum_values=False keeps enums as objects during validation.
+    Serialization to names happens in model_dump() method.
+    """
 
     model_config = ConfigDict(
         alias_generator=to_camel,
         populate_by_name=True,
         extra="ignore",  # Ignore unknown fields by default
+        use_enum_values=False,  # Keep enums as objects during validation
     )
 
+    def model_dump(self, **kwargs: Any) -> dict[str, Any]:
+        """Dump model to dict with enums as names by default."""
+        # Default to 'name' mode for enums unless explicitly overridden
+        if "mode" not in kwargs:
+            kwargs["mode"] = "python"
+        result = super().model_dump(**kwargs)
+        # Convert enums to their names
+        converted: dict[str, Any] = self._convert_enums_to_names(result)
+        return converted
 
-class DhwOperationSetting(Enum):
-    """DHW operation setting modes (user-configured heating preferences)."""
+    @staticmethod
+    def _convert_enums_to_names(
+        data: Any, visited: set[int | None] = None
+    ) -> Any:
+        """Recursively convert Enum values to their names.
 
-    HEAT_PUMP = 1
-    ELECTRIC = 2
-    ENERGY_SAVER = 3
-    HIGH_DEMAND = 4
-    VACATION = 5
-    POWER_OFF = 6
+        Args:
+            data: Data to convert
+            visited: Set of visited object ids to detect cycles
 
+        Returns:
+            Data with enums converted to their names
+        """
+        from enum import Enum
 
-class CurrentOperationMode(Enum):
-    """Current operation mode (real-time operational state)."""
+        if visited is None:
+            visited = set()
 
-    STANDBY = 0
-    HEAT_PUMP_MODE = 32
-    HYBRID_EFFICIENCY_MODE = 64
-    HYBRID_BOOST_MODE = 96
-
-
-class TemperatureUnit(Enum):
-    """Temperature unit enumeration."""
-
-    CELSIUS = 1
-    FAHRENHEIT = 2
+        if isinstance(data, Enum):
+            return data.name
+        elif isinstance(data, dict):
+            # Check for circular reference
+            data_id = id(data)
+            if data_id in visited:
+                return data
+            visited.add(data_id)
+            result: dict[Any, Any] = {
+                key: NavienBaseModel._convert_enums_to_names(value, visited)
+                for key, value in data.items()
+            }
+            visited.discard(data_id)
+            return result
+        elif isinstance(data, (list, tuple)):
+            # Check for circular reference
+            data_id = id(data)
+            if data_id in visited:
+                return data
+            visited.add(data_id)
+            converted = [
+                NavienBaseModel._convert_enums_to_names(item, visited)
+                for item in data
+            ]
+            visited.discard(data_id)
+            return type(data)(converted)
+        return data
 
 
 class DeviceInfo(NavienBaseModel):
@@ -123,21 +195,21 @@ class DeviceInfo(NavienBaseModel):
     home_seq: int = 0
     mac_address: str = ""
     additional_value: str = ""
-    device_type: int = 52
+    device_type: DeviceType | int = DeviceType.NPF700_WIFI
     device_name: str = "Unknown"
     connected: int = 0
-    install_type: Optional[str] = None
+    install_type: str | None = None
 
 
 class Location(NavienBaseModel):
     """Location information for a device."""
 
-    state: Optional[str] = None
-    city: Optional[str] = None
-    address: Optional[str] = None
-    latitude: Optional[float] = None
-    longitude: Optional[float] = None
-    altitude: Optional[float] = None
+    state: str | None = None
+    city: str | None = None
+    address: str | None = None
+    latitude: float | None = None
+    longitude: float | None = None
+    altitude: float | None = None
 
 
 class Device(NavienBaseModel):
@@ -152,11 +224,11 @@ class FirmwareInfo(NavienBaseModel):
 
     mac_address: str = ""
     additional_value: str = ""
-    device_type: int = 52
+    device_type: DeviceType | int = DeviceType.NPF700_WIFI
     cur_sw_code: int = 0
     cur_version: int = 0
-    downloaded_version: Optional[int] = None
-    device_group: Optional[str] = None
+    downloaded_version: int | None = None
+    device_group: str | None = None
 
 
 class TOUSchedule(NavienBaseModel):
@@ -185,9 +257,9 @@ class TOUInfo(NavienBaseModel):
         cls,
         obj: Any,
         *,
-        strict: Optional[bool] = None,
-        from_attributes: Optional[bool] = None,
-        context: Optional[dict[str, Any]] = None,
+        strict: bool | None = None,
+        from_attributes: bool | None = None,
+        context: dict[str, Any | None] = None,
         **kwargs: Any,
     ) -> "TOUInfo":
         # Handle nested structure where fields are in 'touInfo'
@@ -230,12 +302,20 @@ class DeviceStatus(NavienBaseModel):
             "(e.g., freeze protection, anti-seize operations)"
         )
     )
-    error_code: int = Field(description="Error code if any fault is detected")
+    error_code: ErrorCode = Field(
+        default=ErrorCode.NO_ERROR,
+        description="Error code if any fault is detected",
+    )
     sub_error_code: int = Field(
         description="Sub error code providing additional error details"
     )
     smart_diagnostic: int = Field(
-        description="Smart diagnostic status for system health monitoring"
+        description=(
+            "Smart diagnostic status code for system health monitoring. "
+            "0 = no diagnostic conditions. "
+            "Non-zero = diagnostic condition detected. "
+            "Specific diagnostic codes are device firmware dependent."
+        )
     )
     fault_status1: int = Field(description="Fault status register 1")
     fault_status2: int = Field(description="Fault status register 2")
@@ -256,11 +336,14 @@ class DeviceStatus(NavienBaseModel):
         ),
         json_schema_extra={"unit_of_measurement": "%"},
     )
-    dr_event_status: int = Field(
+    dr_event_status: DREvent = Field(
+        default=DREvent.UNKNOWN,
         description=(
-            "Demand Response (DR) event status. "
-            "Indicates if utility DR commands are active (CTA-2045)"
-        )
+            "Demand Response (DR) event status from utility (CTA-2045). "
+            "0=UNKNOWN (No event), 1=RUN_NORMAL, 2=SHED (reduce power), "
+            "3=LOADUP (pre-heat), 4=LOADUP_ADV (advanced pre-heat), "
+            "5=CPE (customer peak event/grid emergency)"
+        ),
     )
     vacation_day_setting: int = Field(
         description="Vacation day setting",
@@ -279,7 +362,7 @@ class DeviceStatus(NavienBaseModel):
     program_reservation_type: int = Field(
         description="Type of program reservation"
     )
-    temp_formula_type: Union[int, str] = Field(
+    temp_formula_type: TempFormulaType = Field(
         description="Temperature formula type"
     )
     current_statenum: int = Field(description="Current state number")
@@ -332,22 +415,26 @@ class DeviceStatus(NavienBaseModel):
         ),
         json_schema_extra={"unit_of_measurement": "gal"},
     )
-    tou_status: int = Field(
+    tou_status: TouStatus = Field(
         description=(
-            "Time of Use (TOU) status - "
-            "indicates if TOU scheduled operation is active"
+            "Time of Use (TOU) scheduling enabled. "
+            "True = TOU is active/enabled, False = TOU is disabled"
         )
     )
     dr_override_status: int = Field(
         description=(
-            "Demand Response override status. "
-            "User can override DR commands for up to 72 hours"
-        )
+            "Demand Response override status in hours. "
+            "0 = no override active. "
+            "Non-zero (1-72) = override active with specified remaining hours. "
+            "User can override DR commands for up to 72 hours."
+        ),
+        json_schema_extra={"unit_of_measurement": "hours"},
     )
-    tou_override_status: int = Field(
+    tou_override_status: TouOverride = Field(
         description=(
-            "Time of Use override status. "
-            "User can temporarily override TOU schedule"
+            "TOU override status. "
+            "True = user has overridden TOU to force immediate heating, "
+            "False = device follows TOU schedule normally"
         )
     )
     total_energy_capacity: float = Field(
@@ -475,7 +562,13 @@ class DeviceStatus(NavienBaseModel):
     error_buzzer_use: DeviceBool = Field(
         description="Whether the error buzzer is enabled"
     )
-    current_heat_use: DeviceBool = Field(description="Current heat usage")
+    current_heat_use: HeatSource = Field(
+        description=(
+            "Currently active heat source. Indicates which heating "
+            "component(s) are actively running: 0=Unknown/not heating, "
+            "1=Heat Pump, 2=Electric Element, 3=Both simultaneously"
+        )
+    )
     heat_upper_use: DeviceBool = Field(
         description=(
             "Upper electric heating element usage status. "
@@ -640,8 +733,8 @@ class DeviceStatus(NavienBaseModel):
     )
 
     # Fields with scale division (raw / 10.0)
-    current_inlet_temperature: Div10 = Field(
-        description="Current inlet temperature",
+    current_inlet_temperature: HalfCelsiusToF = Field(
+        description="Cold water inlet temperature",
         json_schema_extra={
             "unit_of_measurement": "°F",
             "device_class": "temperature",
@@ -797,8 +890,8 @@ class DeviceStatus(NavienBaseModel):
         default=DhwOperationSetting.ENERGY_SAVER,
         description="User's configured DHW operation mode preference",
     )
-    temperature_type: TemperatureUnit = Field(
-        default=TemperatureUnit.FAHRENHEIT,
+    temperature_type: TemperatureType = Field(
+        default=TemperatureType.FAHRENHEIT,
         description="Type of temperature unit",
     )
     freeze_protection_temp_min: HalfCelsiusToF = Field(
@@ -833,7 +926,7 @@ class DeviceFeature(NavienBaseModel):
             "(1=USA, complies with FCC Part 15 Class B)"
         )
     )
-    model_type_code: int = Field(
+    model_type_code: UnitType | int = Field(
         description="Model type identifier: NWP500 series model variant"
     )
     control_type_code: int = Field(
@@ -888,119 +981,118 @@ class DeviceFeature(NavienBaseModel):
             "for warranty and service identification"
         )
     )
-    power_use: int = Field(
-        description=(
-            "Power control capability (1=can be turned on/off via controls)"
-        )
+    power_use: CapabilityFlag = Field(
+        description=("Power control capability (2=supported, 1=not supported)")
     )
-    holiday_use: int = Field(
+    holiday_use: CapabilityFlag = Field(
         description=(
-            "Vacation mode support (1=supported) - "
+            "Vacation mode support (2=supported, 1=not supported) - "
             "energy-saving mode for 0-99 days"
         )
     )
-    program_reservation_use: int = Field(
+    program_reservation_use: CapabilityFlag = Field(
         description=(
-            "Scheduled operation support (1=supported) - "
+            "Scheduled operation support (2=supported, 1=not supported) - "
             "programmable heating schedules"
         )
     )
-    dhw_use: int = Field(
+    dhw_use: CapabilityFlag = Field(
         description=(
-            "Domestic hot water functionality (1=available) - "
+            "Domestic hot water functionality (2=supported, 1=not supported) - "
             "primary function of water heater"
         )
     )
-    dhw_temperature_setting_use: int = Field(
+    dhw_temperature_setting_use: CapabilityFlag = Field(
         description=(
-            "Temperature adjustment capability (1=supported) - "
+            "Temperature adjustment capability "
+            "(2=supported, 1=not supported) - "
             "user can modify target temperature"
         )
     )
-    smart_diagnostic_use: int = Field(
+    smart_diagnostic_use: CapabilityFlag = Field(
         description=(
-            "Self-diagnostic capability (1=available) - "
+            "Self-diagnostic capability (2=supported, 1=not supported) - "
             "10-minute startup diagnostic, error code system"
         )
     )
-    wifi_rssi_use: int = Field(
+    wifi_rssi_use: CapabilityFlag = Field(
         description=(
-            "WiFi signal monitoring (1=supported) - "
+            "WiFi signal monitoring (2=supported, 1=not supported) - "
             "reports signal strength in dBm"
         )
     )
-    temp_formula_type: int = Field(
+    temp_formula_type: TempFormulaType = Field(
         description=(
             "Temperature calculation method identifier "
             "for internal sensor calibration"
         )
     )
-    energy_usage_use: int = Field(
+    energy_usage_use: CapabilityFlag = Field(
         description=(
             "Energy monitoring support (1=available) - tracks kWh consumption"
         )
     )
-    freeze_protection_use: int = Field(
+    freeze_protection_use: CapabilityFlag = Field(
         description=(
             "Freeze protection capability (1=available) - "
             "automatic heating when tank drops below threshold"
         )
     )
-    mixing_value_use: int = Field(
+    mixing_value_use: CapabilityFlag = Field(
         description=(
             "Thermostatic mixing valve support (1=available) - "
             "for temperature limiting at point of use"
         )
     )
-    dr_setting_use: int = Field(
+    dr_setting_use: CapabilityFlag = Field(
         description=(
             "Demand Response support (1=available) - "
             "CTA-2045 compliance for utility load management"
         )
     )
-    anti_legionella_setting_use: int = Field(
+    anti_legionella_setting_use: CapabilityFlag = Field(
         description=(
             "Anti-Legionella function (1=available) - "
             "periodic heating to 140°F (60°C) to prevent bacteria"
         )
     )
-    hpwh_use: int = Field(
+    hpwh_use: CapabilityFlag = Field(
         description=(
             "Heat Pump Water Heater mode (1=supported) - "
             "primary efficient heating using refrigeration cycle"
         )
     )
-    dhw_refill_use: int = Field(
+    dhw_refill_use: CapabilityFlag = Field(
         description=(
             "Tank refill detection (1=supported) - "
             "monitors for dry fire conditions during refill"
         )
     )
-    eco_use: int = Field(
+    eco_use: CapabilityFlag = Field(
         description=(
             "ECO safety switch capability (1=available) - "
             "Energy Cut Off high-temperature limit protection"
         )
     )
-    electric_use: int = Field(
+    electric_use: CapabilityFlag = Field(
         description=(
             "Electric-only mode (1=supported) - "
             "heating element only for maximum recovery speed"
         )
     )
-    heatpump_use: int = Field(
+    heatpump_use: CapabilityFlag = Field(
         description=(
             "Heat pump only mode (1=supported) - "
             "most efficient operation using only refrigeration cycle"
         )
     )
-    energy_saver_use: int = Field(
+    energy_saver_use: CapabilityFlag = Field(
         description=(
             "Energy Saver mode (1=supported) - "
             "hybrid efficiency mode balancing speed and efficiency (default)"
         )
     )
-    high_demand_use: int = Field(
+    high_demand_use: CapabilityFlag = Field(
         description=(
             "High Demand mode (1=supported) - "
             "hybrid boost mode prioritizing fast recovery"
@@ -1050,8 +1142,8 @@ class DeviceFeature(NavienBaseModel):
     )
 
     # Enum field
-    temperature_type: TemperatureUnit = Field(
-        default=TemperatureUnit.FAHRENHEIT,
+    temperature_type: TemperatureType = Field(
+        default=TemperatureType.FAHRENHEIT,
         description=(
             "Default temperature unit preference - "
             "factory set to Fahrenheit for USA"
@@ -1068,14 +1160,14 @@ class MqttRequest(NavienBaseModel):
     """MQTT command request payload."""
 
     command: int
-    device_type: int
+    device_type: DeviceType | int
     mac_address: str
     additional_value: str = "..."
-    mode: Optional[str] = None
-    param: list[Union[int, float]] = Field(default_factory=list)
+    mode: str | None = None
+    param: list[int | float] = Field(default_factory=list)
     param_str: str = ""
-    month: Optional[list[int]] = None
-    year: Optional[int] = None
+    month: list[int] | None = None
+    year: int | None = None
 
 
 class MqttCommand(NavienBaseModel):
@@ -1085,7 +1177,7 @@ class MqttCommand(NavienBaseModel):
     session_id: str = Field(alias="sessionID")
     request_topic: str
     response_topic: str
-    request: Union[MqttRequest, dict[str, Any]]
+    request: MqttRequest | dict[str, Any]
     protocol_version: int = 2
 
 
@@ -1153,9 +1245,7 @@ class EnergyUsageResponse(NavienBaseModel):
     total: EnergyUsageTotal
     usage: list[MonthlyEnergyData]
 
-    def get_month_data(
-        self, year: int, month: int
-    ) -> Optional[MonthlyEnergyData]:
+    def get_month_data(self, year: int, month: int) -> MonthlyEnergyData | None:
         """Get energy usage data for a specific month.
 
         Args:
