@@ -5,12 +5,14 @@ This module provides utility functions for redacting sensitive information,
 configuration classes, and common data structures used across MQTT modules.
 """
 
+from __future__ import annotations
+
 import re
 import uuid
 from dataclasses import dataclass
 from datetime import datetime
 from enum import Enum
-from typing import Any, Optional
+from typing import Any
 
 from awscrt import mqtt
 
@@ -29,7 +31,7 @@ _MAC_PATTERNS = [
 ]
 
 
-def redact(obj: Any, keys_to_redact: Optional[set[str]] = None) -> Any:
+def redact(obj: Any, keys_to_redact: set[str] | None = None) -> Any:
     """Return a redacted copy of obj with sensitive keys masked.
 
     This is a lightweight sanitizer for log messages to avoid emitting
@@ -166,7 +168,7 @@ class MqttConnectionConfig:
 
     endpoint: str = AWS_IOT_ENDPOINT
     region: str = AWS_REGION
-    client_id: Optional[str] = None
+    client_id: str | None = None
     clean_session: bool = True
     keep_alive_secs: int = 1200
 
@@ -219,3 +221,62 @@ class PeriodicRequestType(Enum):
 
     DEVICE_INFO = "device_info"
     DEVICE_STATUS = "device_status"
+
+
+def topic_matches_pattern(topic: str, pattern: str) -> bool:
+    """
+    Check if a topic matches a subscription pattern with wildcards.
+
+    Supports MQTT wildcards:
+    - '+' matches a single level
+    - '#' matches multiple levels (must be at end)
+
+    Args:
+        topic: Actual topic (e.g., "cmd/52/navilink-ABC/status")
+        pattern: Pattern with wildcards (e.g., "cmd/52/+/#")
+
+    Returns:
+        True if topic matches pattern
+
+    Examples:
+        >>> topic_matches_pattern("cmd/52/device1/status", "cmd/52/+/status")
+        True
+        >>> topic_matches_pattern(
+        ...     "cmd/52/device1/status/extra", "cmd/52/device1/#"
+        ... )
+        True
+    """
+    # Handle exact match
+    if topic == pattern:
+        return True
+
+    # Handle wildcards
+    topic_parts = topic.split("/")
+    pattern_parts = pattern.split("/")
+
+    # Multi-level wildcard # matches everything after
+    if "#" in pattern_parts:
+        hash_idx = pattern_parts.index("#")
+        # Must be at the end
+        if hash_idx != len(pattern_parts) - 1:
+            return False
+        # Topic must have at least as many parts as before the #
+        if len(topic_parts) < hash_idx:
+            return False
+        # Check parts before # with + wildcard support
+        for i in range(hash_idx):
+            if pattern_parts[i] != "+" and topic_parts[i] != pattern_parts[i]:
+                return False
+        return True
+
+    # Single-level wildcard + matches one level
+    if len(topic_parts) != len(pattern_parts):
+        return False
+
+    for topic_part, pattern_part in zip(
+        topic_parts, pattern_parts, strict=True
+    ):
+        if pattern_part != "+" and topic_part != pattern_part:
+            return False
+
+    return True
